Method: AppMath::Graph#ipos

Defined in:
lib/graph.rb

#ipos(x, y) ⇒ Object

integer (pixel-wise) position associated with a point (x,y) in x,y-space. Notice that this is given by a simple (and efficient) formula if the auxiliar quantities @a, @b, @c, @d got their value by means of the next two functions.



217
218
219
# File 'lib/graph.rb', line 217

def ipos x, y
  [@a + @b * x, @c + @d * y]
end